==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/WebKit/Shared/WebGPU/WebGPUExtent3D.cpp <==
/*
 * Copyright (C) 2021-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUExtent3D.h"

#if ENABLE(GPU_PROCESS)

#include "WebGPUConvertFromBackingContext.h"
#include "WebGPUConvertToBackingContext.h"
#include <WebCore/WebGPUExtent3D.h>

namespace WebKit::WebGPU {

std::optional<Extent3DDict> ConvertToBackingContext::convertToBacking(const WebCore::WebGPU::Extent3DDict& extent3DDict)
{
    return { { extent3DDict.width, extent3DDict.height, extent3DDict.depthOrArrayLayers } };
}

std::optional<Extent3D> ConvertToBackingContext::convertToBacking(const WebCore::WebGPU::Extent3D& extent3D)
{
    return WTF::switchOn(extent3D, [] (const Vector<WebCore::WebGPU::IntegerCoordinate>& vector) -> std::optional<Extent3D> {
        return { { vector } };
    }, [this] (const WebCore::WebGPU::Extent3DDict& extent3DDict) -> std::optional<Extent3D> {
        auto extent3D = convertToBacking(extent3DDict);
        if (!extent3D)
            return std::nullopt;
        return { { WTFMove(*extent3D) } };
    });
}

std::optional<WebCore::WebGPU::Extent3DDict> ConvertFromBackingContext::convertFromBacking(const Extent3DDict& extent3DDict)
{
    return { { extent3DDict.width, extent3DDict.height, extent3DDict.depthOrArrayLayers } };
}

std::optional<WebCore::WebGPU::Extent3D> ConvertFromBackingContext::convertFromBacking(const Extent3D& extent3D)
{
    return WTF::switchOn(extent3D, [] (const Vector<WebCore::WebGPU::IntegerCoordinate>& vector) -> std::optional<WebCore::WebGPU::Extent3D> {
        return { { vector } };
    }, [this] (const Extent3DDict& extent3DDict) -> std::optional<WebCore::WebGPU::Extent3D> {
        auto extent3D = convertFromBacking(extent3DDict);
        if (!extent3D)
            return std::nullopt;
        return { { WTFMove(*extent3D) } };
    });
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS)

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebKit/Shared/WebGPU/WebGPUExtent3D.cpp <==
/*
 * Copyright (C) 2021-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUExtent3D.h"

#if ENABLE(GPU_PROCESS)

#include "WebGPUConvertFromBackingContext.h"
#include "WebGPUConvertToBackingContext.h"
#include <WebCore/WebGPUExtent3D.h>

namespace WebKit::WebGPU {

std::optional<Extent3DDict> ConvertToBackingContext::convertToBacking(const WebCore::WebGPU::Extent3DDict& extent3DDict)
{
    return { { extent3DDict.width, extent3DDict.height, extent3DDict.depthOrArrayLayers } };
}

std::optional<Extent3D> ConvertToBackingContext::convertToBacking(const WebCore::WebGPU::Extent3D& extent3D)
{
    return WTF::switchOn(extent3D, [] (const Vector<WebCore::WebGPU::IntegerCoordinate>& vector) -> std::optional<Extent3D> {
        return { { vector } };
    }, [this] (const WebCore::WebGPU::Extent3DDict& extent3DDict) -> std::optional<Extent3D> {
        auto extent3D = convertToBacking(extent3DDict);
        if (!extent3D)
            return std::nullopt;
        return { { WTF::move(*extent3D) } };
    });
}

std::optional<WebCore::WebGPU::Extent3DDict> ConvertFromBackingContext::convertFromBacking(const Extent3DDict& extent3DDict)
{
    return { { extent3DDict.width, extent3DDict.height, extent3DDict.depthOrArrayLayers } };
}

std::optional<WebCore::WebGPU::Extent3D> ConvertFromBackingContext::convertFromBacking(const Extent3D& extent3D)
{
    return WTF::switchOn(extent3D, [] (const Vector<WebCore::WebGPU::IntegerCoordinate>& vector) -> std::optional<WebCore::WebGPU::Extent3D> {
        return { { vector } };
    }, [this] (const Extent3DDict& extent3DDict) -> std::optional<WebCore::WebGPU::Extent3D> {
        auto extent3D = convertFromBacking(extent3DDict);
        if (!extent3D)
            return std::nullopt;
        return { { WTF::move(*extent3D) } };
    });
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS)
